Release History
===============

dev
---

**Bugfixes**

-   \[Short description of non-trivial change.\]

0.1.1 (09-02-2020)
------------------
- Fix update events


0.1.0 (09-02-2020)
-----------------
- Initial version


0.0.2-alpha1 (05-02-2020)
-------------------------

- Usable version for some integration

0.0.1-alpha1 (03-02-2020)
-------------------------
Good start definition from requests project [https://requests.readthedocs.io] HISTORY.md :)

-   Frustration
-   Conception
